#
# spec file for package python-django-avatar
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-avatar
Version:        8.0.1
Release:        2.1
Summary:        Django-avatar package
License:        BSD-3-Clause
URL:            https://github.com/grantmcconnaughey/django-avatar/
Source:         https://github.com/jazzband/django-avatar/archive/refs/tags/v%{version}.tar.gz#/django-avatar-%{version}.tar.gz
BuildRequires:  %{python_module Django >= 4.0}
BuildRequires:  %{python_module Pillow >= 8.4}
BuildRequires:  %{python_module django-appconf >= 1.0.5}
BuildRequires:  %{python_module dnspython >= 2.3.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module python-magic}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 4.0
Requires:       python-Pillow >= 8.4
Requires:       python-django-appconf >= 1.0.5
Requires:       python-dnspython >= 2.3.0
BuildArch:      noarch
%python_subpackages

%description
Django-avatar is a reusable application for handling user avatars.  It has the
ability to default to Gravatar_ if no avatar is found for a certain user.
Django-avatar automatically generates thumbnails and stores them to your default
file storage backend for retrieval later.

%prep
%autosetup -p1 -n django-avatar-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand %{_bindir}/django-admin-%{$python_bin_suffix} test --settings=tests.settings --pythonpath=`pwd`

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/avatar
%{python_sitelib}/django_avatar-%{version}.dist-info

%changelog
* Thu Feb  6 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Tue Oct 22 2024 Dirk Müller <dmueller@suse.com>
- update to 8.0.1:
  * Fix Django 5.1 compatibility
* Thu Mar 28 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 8.0.0:
  * Add Django 4.2 support
  * Remove Python 3.7 support
  * Use path and path converters (changes all url names from
    prefix `avatar_` to `avatar:`.)
  * Add support for Django STORAGES (Django 4.2)
  * Add optional api app (requires djangorestframework)
  * Use ``Image.Resampling.LANCZOS`` instead of ``Image.LANCZOS``
    that was removed in Pillow 10.0.0
* Fri Mar 31 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 7.1.1:
  * Switch to setuptools for building
  * Add LibRavatar support
  * Faster admin when many users are present
  * Check for corrupted image during upload
  * Switch Pillow Resize method from Image.ANTIALIAS to Image.LANCZOS
  * Removed Python 3.6 testing
  * Added Python 3.11 support
  * Remove height requirement for providers (broke 6 to 7 upgrades)
  * Allowed for rectangular avatars. Custom avatar tag templates now require
    the specification of both a width and height attribute instead of size.
  * Made True the default value of AVATAR_CLEANUP_DELETED.
  * Fix invalidate_cache for on-the-fly created thumbnails.
  * New setting AVATAR_ALLOWED_MIMETYPES. If enabled, it checks mimetypes of
    uploaded files using python-magic. Default is None.
  * Fix thumbnail transposing for Safari.
  * Added Django 3.2, 4.0 and 4.1 support.
  * Removed Django 1.9, 1.10, 1.11, 2.0, 2.1, 2.2 and 3.0 support.
  * Added Python 3.9 and 3.10 support.
  * Removed Python 2.7, 3.4 and 3.5 support.
  * Made "PNG" the default value for AVATAR_THUMB_FORMAT.
  * Made False the default value for AVATAR_EXPOSE_USERNAMES.
  * Don't leak usernames through image alt-tags when AVATAR_EXPOSE_USERNAMES
    is False.
  * Use original image as thumbnail if thumbnail creation failed but image
    saving succeeds.
- Remove patch support-django-40.patch, no longer required.
* Thu Feb  3 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-django-40.patch:
  * Support Django 4.0.
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 5.0.0:
  * Added Django 2.1, 2.2, and 3.0 support.
  * Added Python 3.7 and 3.8 support.
  * Fixed bug where avatars couldn't be deleted if file was already deleted.
* Fri Sep 13 2019 John Vandenberg <jayvdb@gmail.com>
- Skip the check if flavor python2 is not being built
* Thu Jan  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Sadly the tests are working only under django 1.11 thus
  skip them on py3
* Mon Dec 10 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.1.0:
  * py3 support
  * new django 1.11 and 2.0 support
* Fri Sep 27 2013 p.drouand@gmail.com
- Update to version 2.0
  + No changelog available
- Cleanup specfile
- Replace python-ditribute with python-setuptools BuildRequires
* Tue Mar 13 2012 saschpe@suse.de
- Add %%changelog line
* Mon Mar 12 2012 saschpe@gmx.de
- Spec file cleanup
* Mon Jul  5 2010 alexandre@exatati.com.br
- Update to 1.0.5.
* Tue Mar 16 2010 alexandre@exatati.com.br
- Update to 1.0.4.
* Mon Nov  9 2009 alexandre@exatati.com.br
- Update to 1.0.3;
- Building as noarch for openSUSE >= 11.2.
* Thu Aug 13 2009 alexandre@exatati.com.br
- Initial version (1.0.1) for openSUSE.
